@@ -178,25 +178,6 @@ def common(**kwargs):
     COMPRESS_URL = "/media/"
     COMPRESS_ROOT = STATIC_ROOT
 
-    LOGGING = {
-        'version': 1,
-        'disable_existing_loggers': False,
-        'handlers': {
-            'file': {
-                'level': 'DEBUG',
-                'class': 'logging.FileHandler',
-                'filename': '/var/log/django/' + project + '/debug.log',
-            },
-        },
-        'loggers': {
-            'django': {
-                'handlers': ['file'],
-                'level': 'DEBUG',
-                'propagate': True,
-            },
-        },
-    }
-
     GRAPHITE_BASE = "https://graphite.ctl.columbia.edu/render/"
 
     return locals()
